@@ -18,9 +18,10 @@ require_account_actions = ['login', 'query_info', 'keep_alive']
 
 APP_NAME = '.bjutInternet'
 CONFIG_FILE = get_working_file(APP_NAME)
+CURRENT_VERSION = '0.1.13'
 
 def main():
-    parser = argparse.ArgumentParser(prog='bjutlogin', description="BJUT Login command line tools.")
+    parser = argparse.ArgumentParser(prog='bjutlogin', description='BJUT Login command line tool.')
     parser.add_argument('--username', '-u', type=str, default=None, help='校园网账号')
     parser.add_argument('--password', '-p', type=str, default=None, help='校园网密码')
     parser.add_argument('--type', '-t', type=str, help='IPv4(4)、IPv6(6) or All 默认为同时登录v4与v6', default='All')
@@ -29,6 +30,7 @@ def main():
     action_group.add_argument('--logout', action ='store_true', help='注销')
     action_group.add_argument('--keep-alive', '-k', action='store_true', help='保持登录状态，掉线后自动重连')
     action_group.add_argument('--query', '-q', action='store_true', help='查询校园网账户信息')
+    action_group.add_argument('--version', action='store_true', help='查看版本及检查是否有新版本')
     parser.add_argument('--remember', action='store_true', help='记住账号密码')
     connection_group = parser.add_mutually_exclusive_group()
     connection_group.add_argument('--wire', action ='store_true', help='有线连接')
@@ -36,6 +38,17 @@ def main():
 
     args = parser.parse_args()
 
+    # 版本检查
+    if args.version:
+        print(CURRENT_VERSION)
+        try:
+            need_update, new_version = check_version(CURRENT_VERSION)
+        except Exception as e:
+            need_update, new_version = False, None
+        if need_update:
+            print('存在新版本 {}\n可运行 pip install -U bjut-internet-login-tool 进行更新'.format(new_version))
+        exit()
+
     action = None
     login_type = parse_internet_type(args.type)
     network_type = None
